# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: confidence/flags/resolver/v1/types.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'confidence/flags/resolver/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(confidence/flags/resolver/v1/types.proto\x12\x1c\x63onfidence.flags.resolver.v1\"e\n\x03Sdk\x12\x31\n\x02id\x18\x01 \x01(\x0e\x32#.confidence.flags.resolver.v1.SdkIdH\x00\x12\x13\n\tcustom_id\x18\x02 \x01(\tH\x00\x12\x0f\n\x07version\x18\x03 \x01(\tB\x05\n\x03sdk*\xa4\x03\n\rResolveReason\x12\x1e\n\x1aRESOLVE_REASON_UNSPECIFIED\x10\x00\x12\x18\n\x14RESOLVE_REASON_MATCH\x10\x01\x12#\n\x1fRESOLVE_REASON_NO_SEGMENT_MATCH\x10\x02\x12)\n!RESOLVE_REASON_NO_TREATMENT_MATCH\x10\x03\x1a\x02\x08\x01\x12 \n\x1cRESOLVE_REASON_FLAG_ARCHIVED\x10\x04\x12&\n\"RESOLVE_REASON_TARGETING_KEY_ERROR\x10\x05\x12\x18\n\x14RESOLVE_REASON_ERROR\x10\x06\x12.\n*RESOLVE_REASON_UNRECOGNIZED_TARGETING_RULE\x10\x07\x12\x30\n,RESOLVE_REASON_MATERIALIZATION_NOT_SUPPORTED\x10\x08\x12 \n\x1cRESOLVE_REASON_TYPE_MISMATCH\x10\t\x12!\n\x1dRESOLVE_REASON_FLAG_NOT_FOUND\x10\n*\xa3\x05\n\x05SdkId\x12\x16\n\x12SDK_ID_UNSPECIFIED\x10\x00\x12\x18\n\x14SDK_ID_JAVA_PROVIDER\x10\x01\x12\x1a\n\x16SDK_ID_KOTLIN_PROVIDER\x10\x02\x12\x19\n\x15SDK_ID_SWIFT_PROVIDER\x10\x03\x12\x1a\n\x16SDK_ID_JS_WEB_PROVIDER\x10\x04\x12\x1d\n\x19SDK_ID_JS_SERVER_PROVIDER\x10\x05\x12\x1a\n\x16SDK_ID_PYTHON_PROVIDER\x10\x06\x12\x16\n\x12SDK_ID_GO_PROVIDER\x10\x07\x12\x18\n\x14SDK_ID_RUBY_PROVIDER\x10\x08\x12\x18\n\x14SDK_ID_RUST_PROVIDER\x10\t\x12\x1a\n\x16SDK_ID_JAVA_CONFIDENCE\x10\n\x12\x1c\n\x18SDK_ID_KOTLIN_CONFIDENCE\x10\x0b\x12\x1b\n\x17SDK_ID_SWIFT_CONFIDENCE\x10\x0c\x12\x18\n\x14SDK_ID_JS_CONFIDENCE\x10\r\x12\x1c\n\x18SDK_ID_PYTHON_CONFIDENCE\x10\x0e\x12\x18\n\x14SDK_ID_GO_CONFIDENCE\x10\x0f\x12\x1a\n\x16SDK_ID_RUST_CONFIDENCE\x10\x10\x12!\n\x1dSDK_ID_FLUTTER_IOS_CONFIDENCE\x10\x11\x12%\n!SDK_ID_FLUTTER_ANDROID_CONFIDENCE\x10\x12\x12\x1c\n\x18SDK_ID_DOTNET_CONFIDENCE\x10\x13\x12\x1c\n\x18SDK_ID_GO_LOCAL_PROVIDER\x10\x14\x12\x1e\n\x1aSDK_ID_JAVA_LOCAL_PROVIDER\x10\x15\x12#\n\x1fSDK_ID_JS_LOCAL_SERVER_PROVIDER\x10\x16\x42\x9f\x01\n,com.spotify.confidence.sdk.flags.resolver.v1B\nTypesProtoP\x01Zagithub.com/spotify/confidence-resolver/openfeature-provider/go/confidence/internal/proto/resolverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'confidence.flags.resolver.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,com.spotify.confidence.sdk.flags.resolver.v1B\nTypesProtoP\001Zagithub.com/spotify/confidence-resolver/openfeature-provider/go/confidence/internal/proto/resolver'
  _globals['_RESOLVEREASON'].values_by_name["RESOLVE_REASON_NO_TREATMENT_MATCH"]._loaded_options = None
  _globals['_RESOLVEREASON'].values_by_name["RESOLVE_REASON_NO_TREATMENT_MATCH"]._serialized_options = b'\010\001'
  _globals['_RESOLVEREASON']._serialized_start=178
  _globals['_RESOLVEREASON']._serialized_end=598
  _globals['_SDKID']._serialized_start=601
  _globals['_SDKID']._serialized_end=1276
  _globals['_SDK']._serialized_start=74
  _globals['_SDK']._serialized_end=175
# @@protoc_insertion_point(module_scope)
