# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: confidence/wasm/messages.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'confidence/wasm/messages.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..flags.resolver.v1 import types_pb2 as confidence_dot_flags_dot_resolver_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63onfidence/wasm/messages.proto\x12\x0f\x63onfidence.wasm\x1a(confidence/flags/resolver/v1/types.proto\"\x06\n\x04Void\"l\n\x17SetResolverStateRequest\x12\r\n\x05state\x18\x01 \x01(\x0c\x12\x12\n\naccount_id\x18\x02 \x01(\t\x12.\n\x03sdk\x18\x03 \x01(\x0b\x32!.confidence.flags.resolver.v1.Sdk\"\x17\n\x07Request\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"5\n\x08Response\x12\x0e\n\x04\x64\x61ta\x18\x01 \x01(\x0cH\x00\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x42\x08\n\x06result\"-\n\x19PrometheusSnapshotRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"*\n\x1aPrometheusSnapshotResponse\x12\x0c\n\x04text\x18\x01 \x01(\tB\x8c\x01\n\x1f\x63om.spotify.confidence.sdk.wasmB\x08MessagesP\x00Z]github.com/spotify/confidence-resolver/openfeature-provider/go/confidence/internal/proto/wasmb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'confidence.wasm.messages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.spotify.confidence.sdk.wasmB\010MessagesP\000Z]github.com/spotify/confidence-resolver/openfeature-provider/go/confidence/internal/proto/wasm'
  _globals['_VOID']._serialized_start=93
  _globals['_VOID']._serialized_end=99
  _globals['_SETRESOLVERSTATEREQUEST']._serialized_start=101
  _globals['_SETRESOLVERSTATEREQUEST']._serialized_end=209
  _globals['_REQUEST']._serialized_start=211
  _globals['_REQUEST']._serialized_end=234
  _globals['_RESPONSE']._serialized_start=236
  _globals['_RESPONSE']._serialized_end=289
  _globals['_PROMETHEUSSNAPSHOTREQUEST']._serialized_start=291
  _globals['_PROMETHEUSSNAPSHOTREQUEST']._serialized_end=336
  _globals['_PROMETHEUSSNAPSHOTRESPONSE']._serialized_start=338
  _globals['_PROMETHEUSSNAPSHOTRESPONSE']._serialized_end=380
# @@protoc_insertion_point(module_scope)
