# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: confidence/flags/resolver/v1/api.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'confidence/flags/resolver/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import types_pb2 as confidence_dot_flags_dot_resolver_dot_v1_dot_types__pb2
from ...types.v1 import types_pb2 as confidence_dot_flags_dot_types_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&confidence/flags/resolver/v1/api.proto\x12\x1c\x63onfidence.flags.resolver.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a(confidence/flags/resolver/v1/types.proto\x1a%confidence/flags/types/v1/types.proto\"\xaf\x01\n\x13ResolveFlagsRequest\x12\r\n\x05\x66lags\x18\x01 \x03(\t\x12\x33\n\x12\x65valuation_context\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rclient_secret\x18\x03 \x01(\t\x12\r\n\x05\x61pply\x18\x04 \x01(\x08\x12.\n\x03sdk\x18\x05 \x01(\x0b\x32!.confidence.flags.resolver.v1.Sdk\"\x85\x01\n\x14ResolveFlagsResponse\x12\x42\n\x0eresolved_flags\x18\x01 \x03(\x0b\x32*.confidence.flags.resolver.v1.ResolvedFlag\x12\x15\n\rresolve_token\x18\x02 \x01(\x0c\x12\x12\n\nresolve_id\x18\x03 \x01(\t\"\xda\x01\n\x11\x41pplyFlagsRequest\x12\x38\n\x05\x66lags\x18\x01 \x03(\x0b\x32).confidence.flags.resolver.v1.AppliedFlag\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x15\n\rresolve_token\x18\x03 \x01(\x0c\x12-\n\tsend_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\x03sdk\x18\x05 \x01(\x0b\x32!.confidence.flags.resolver.v1.Sdk\"\x14\n\x12\x41pplyFlagsResponse\"K\n\x0b\x41ppliedFlag\x12\x0c\n\x04\x66lag\x18\x01 \x01(\t\x12.\n\napply_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xf5\x01\n\x0cResolvedFlag\x12\x0c\n\x04\x66lag\x18\x01 \x01(\t\x12\x0f\n\x07variant\x18\x02 \x01(\t\x12&\n\x05value\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12K\n\x0b\x66lag_schema\x18\x04 \x01(\x0b\x32\x36.confidence.flags.types.v1.FlagSchema.StructFlagSchema\x12;\n\x06reason\x18\x05 \x01(\x0e\x32+.confidence.flags.resolver.v1.ResolveReason\x12\x14\n\x0cshould_apply\x18\x06 \x01(\x08\x32\x8e\x01\n\x13\x46lagResolverService\x12w\n\x0cResolveFlags\x12\x31.confidence.flags.resolver.v1.ResolveFlagsRequest\x1a\x32.confidence.flags.resolver.v1.ResolveFlagsResponse\"\x00\x42\x9d\x01\n,com.spotify.confidence.sdk.flags.resolver.v1B\x08\x41piProtoP\x01Zagithub.com/spotify/confidence-resolver/openfeature-provider/go/confidence/internal/proto/resolverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'confidence.flags.resolver.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,com.spotify.confidence.sdk.flags.resolver.v1B\010ApiProtoP\001Zagithub.com/spotify/confidence-resolver/openfeature-provider/go/confidence/internal/proto/resolver'
  _globals['_RESOLVEFLAGSREQUEST']._serialized_start=217
  _globals['_RESOLVEFLAGSREQUEST']._serialized_end=392
  _globals['_RESOLVEFLAGSRESPONSE']._serialized_start=395
  _globals['_RESOLVEFLAGSRESPONSE']._serialized_end=528
  _globals['_APPLYFLAGSREQUEST']._serialized_start=531
  _globals['_APPLYFLAGSREQUEST']._serialized_end=749
  _globals['_APPLYFLAGSRESPONSE']._serialized_start=751
  _globals['_APPLYFLAGSRESPONSE']._serialized_end=771
  _globals['_APPLIEDFLAG']._serialized_start=773
  _globals['_APPLIEDFLAG']._serialized_end=848
  _globals['_RESOLVEDFLAG']._serialized_start=851
  _globals['_RESOLVEDFLAG']._serialized_end=1096
  _globals['_FLAGRESOLVERSERVICE']._serialized_start=1099
  _globals['_FLAGRESOLVERSERVICE']._serialized_end=1241
# @@protoc_insertion_point(module_scope)
