# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: confidence/flags/types/v1/types.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'confidence/flags/types/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%confidence/flags/types/v1/types.proto\x12\x19\x63onfidence.flags.types.v1\"\xce\x06\n\nFlagSchema\x12O\n\rstruct_schema\x18\x01 \x01(\x0b\x32\x36.confidence.flags.types.v1.FlagSchema.StructFlagSchemaH\x00\x12K\n\x0blist_schema\x18\x02 \x01(\x0b\x32\x34.confidence.flags.types.v1.FlagSchema.ListFlagSchemaH\x00\x12I\n\nint_schema\x18\x03 \x01(\x0b\x32\x33.confidence.flags.types.v1.FlagSchema.IntFlagSchemaH\x00\x12O\n\rdouble_schema\x18\x04 \x01(\x0b\x32\x36.confidence.flags.types.v1.FlagSchema.DoubleFlagSchemaH\x00\x12O\n\rstring_schema\x18\x05 \x01(\x0b\x32\x36.confidence.flags.types.v1.FlagSchema.StringFlagSchemaH\x00\x12K\n\x0b\x62ool_schema\x18\x06 \x01(\x0b\x32\x34.confidence.flags.types.v1.FlagSchema.BoolFlagSchemaH\x00\x1a\xbc\x01\n\x10StructFlagSchema\x12R\n\x06schema\x18\x01 \x03(\x0b\x32\x42.confidence.flags.types.v1.FlagSchema.StructFlagSchema.SchemaEntry\x1aT\n\x0bSchemaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.confidence.flags.types.v1.FlagSchema:\x02\x38\x01\x1a\x12\n\x10\x44oubleFlagSchema\x1a\x0f\n\rIntFlagSchema\x1a\x12\n\x10StringFlagSchema\x1a\x10\n\x0e\x42oolFlagSchema\x1aO\n\x0eListFlagSchema\x12=\n\x0e\x65lement_schema\x18\x01 \x01(\x0b\x32%.confidence.flags.types.v1.FlagSchemaB\r\n\x0bschema_typeB\x99\x01\n)com.spotify.confidence.sdk.flags.types.v1B\nTypesProtoP\x01Z^github.com/spotify/confidence-resolver/openfeature-provider/go/confidence/internal/proto/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'confidence.flags.types.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.spotify.confidence.sdk.flags.types.v1B\nTypesProtoP\001Z^github.com/spotify/confidence-resolver/openfeature-provider/go/confidence/internal/proto/types'
  _globals['_FLAGSCHEMA_STRUCTFLAGSCHEMA_SCHEMAENTRY']._loaded_options = None
  _globals['_FLAGSCHEMA_STRUCTFLAGSCHEMA_SCHEMAENTRY']._serialized_options = b'8\001'
  _globals['_FLAGSCHEMA']._serialized_start=69
  _globals['_FLAGSCHEMA']._serialized_end=915
  _globals['_FLAGSCHEMA_STRUCTFLAGSCHEMA']._serialized_start=556
  _globals['_FLAGSCHEMA_STRUCTFLAGSCHEMA']._serialized_end=744
  _globals['_FLAGSCHEMA_STRUCTFLAGSCHEMA_SCHEMAENTRY']._serialized_start=660
  _globals['_FLAGSCHEMA_STRUCTFLAGSCHEMA_SCHEMAENTRY']._serialized_end=744
  _globals['_FLAGSCHEMA_DOUBLEFLAGSCHEMA']._serialized_start=746
  _globals['_FLAGSCHEMA_DOUBLEFLAGSCHEMA']._serialized_end=764
  _globals['_FLAGSCHEMA_INTFLAGSCHEMA']._serialized_start=766
  _globals['_FLAGSCHEMA_INTFLAGSCHEMA']._serialized_end=781
  _globals['_FLAGSCHEMA_STRINGFLAGSCHEMA']._serialized_start=783
  _globals['_FLAGSCHEMA_STRINGFLAGSCHEMA']._serialized_end=801
  _globals['_FLAGSCHEMA_BOOLFLAGSCHEMA']._serialized_start=803
  _globals['_FLAGSCHEMA_BOOLFLAGSCHEMA']._serialized_end=819
  _globals['_FLAGSCHEMA_LISTFLAGSCHEMA']._serialized_start=821
  _globals['_FLAGSCHEMA_LISTFLAGSCHEMA']._serialized_end=900
# @@protoc_insertion_point(module_scope)
