# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: confidence/wasm/wasm_api.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'confidence/wasm/wasm_api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..flags.resolver.v1 import api_pb2 as confidence_dot_flags_dot_resolver_dot_v1_dot_api__pb2
from ..flags.resolver.v1 import types_pb2 as confidence_dot_flags_dot_resolver_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63onfidence/wasm/wasm_api.proto\x12\x1c\x63onfidence.flags.resolver.v1\x1a&confidence/flags/resolver/v1/api.proto\x1a(confidence/flags/resolver/v1/types.proto\"\xac\x05\n\x15ResolveProcessRequest\x12V\n\x19\x64\x65\x66\x65rred_materializations\x18\x01 \x01(\x0b\x32\x31.confidence.flags.resolver.v1.ResolveFlagsRequestH\x00\x12m\n\x17static_materializations\x18\x02 \x01(\x0b\x32J.confidence.flags.resolver.v1.ResolveProcessRequest.StaticMaterializationsH\x00\x12U\n\x18without_materializations\x18\x03 \x01(\x0b\x32\x31.confidence.flags.resolver.v1.ResolveFlagsRequestH\x00\x12L\n\x06resume\x18\x04 \x01(\x0b\x32:.confidence.flags.resolver.v1.ResolveProcessRequest.ResumeH\x00\x1a\xb3\x01\n\x16StaticMaterializations\x12J\n\x0fresolve_request\x18\x01 \x01(\x0b\x32\x31.confidence.flags.resolver.v1.ResolveFlagsRequest\x12M\n\x10materializations\x18\x02 \x03(\x0b\x32\x33.confidence.flags.resolver.v1.MaterializationRecord\x1a\x66\n\x06Resume\x12M\n\x10materializations\x18\x01 \x03(\x0b\x32\x33.confidence.flags.resolver.v1.MaterializationRecord\x12\r\n\x05state\x18\x02 \x01(\x0c\x42\t\n\x07resolve\"\xe8\x03\n\x16ResolveProcessResponse\x12Q\n\x08resolved\x18\x01 \x01(\x0b\x32=.confidence.flags.resolver.v1.ResolveProcessResponse.ResolvedH\x00\x12S\n\tsuspended\x18\x02 \x01(\x0b\x32>.confidence.flags.resolver.v1.ResolveProcessResponse.SuspendedH\x00\x1a\xa8\x01\n\x08Resolved\x12\x44\n\x08response\x18\x01 \x01(\x0b\x32\x32.confidence.flags.resolver.v1.ResolveFlagsResponse\x12V\n\x19materializations_to_write\x18\x02 \x03(\x0b\x32\x33.confidence.flags.resolver.v1.MaterializationRecord\x1aq\n\tSuspended\x12U\n\x18materializations_to_read\x18\x01 \x03(\x0b\x32\x33.confidence.flags.resolver.v1.MaterializationRecord\x12\r\n\x05state\x18\x02 \x01(\x0c\x42\x08\n\x06result\"]\n\x15MaterializationRecord\x12\x0c\n\x04unit\x18\x01 \x01(\t\x12\x17\n\x0fmaterialization\x18\x02 \x01(\t\x12\x0c\n\x04rule\x18\x03 \x01(\t\x12\x0f\n\x07variant\x18\x04 \x01(\t\"\x1d\n\nLogMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\"i\n\x16RegisterResolveRequest\x12;\n\x06reason\x18\x01 \x01(\x0e\x32+.confidence.flags.resolver.v1.ResolveReason\x12\x12\n\nlatency_us\x18\x02 \x01(\rB\x9d\x01\n,com.spotify.confidence.sdk.flags.resolver.v1B\x0cWasmApiProtoP\x01Z]github.com/spotify/confidence-resolver/openfeature-provider/go/confidence/internal/proto/wasmb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'confidence.wasm.wasm_api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,com.spotify.confidence.sdk.flags.resolver.v1B\014WasmApiProtoP\001Z]github.com/spotify/confidence-resolver/openfeature-provider/go/confidence/internal/proto/wasm'
  _globals['_RESOLVEPROCESSREQUEST']._serialized_start=147
  _globals['_RESOLVEPROCESSREQUEST']._serialized_end=831
  _globals['_RESOLVEPROCESSREQUEST_STATICMATERIALIZATIONS']._serialized_start=537
  _globals['_RESOLVEPROCESSREQUEST_STATICMATERIALIZATIONS']._serialized_end=716
  _globals['_RESOLVEPROCESSREQUEST_RESUME']._serialized_start=718
  _globals['_RESOLVEPROCESSREQUEST_RESUME']._serialized_end=820
  _globals['_RESOLVEPROCESSRESPONSE']._serialized_start=834
  _globals['_RESOLVEPROCESSRESPONSE']._serialized_end=1322
  _globals['_RESOLVEPROCESSRESPONSE_RESOLVED']._serialized_start=1029
  _globals['_RESOLVEPROCESSRESPONSE_RESOLVED']._serialized_end=1197
  _globals['_RESOLVEPROCESSRESPONSE_SUSPENDED']._serialized_start=1199
  _globals['_RESOLVEPROCESSRESPONSE_SUSPENDED']._serialized_end=1312
  _globals['_MATERIALIZATIONRECORD']._serialized_start=1324
  _globals['_MATERIALIZATIONRECORD']._serialized_end=1417
  _globals['_LOGMESSAGE']._serialized_start=1419
  _globals['_LOGMESSAGE']._serialized_end=1448
  _globals['_REGISTERRESOLVEREQUEST']._serialized_start=1450
  _globals['_REGISTERRESOLVEREQUEST']._serialized_end=1555
# @@protoc_insertion_point(module_scope)
